@@ -13,14 +13,20 @@
 #limitations under the License.
 #
 """Chef Solo deployment"""
+import os
+
 from fabric.api import *
-from fabric.contrib.files import append, exists
+from fabric import colors
+from fabric.contrib.files import append, exists, upload_template
 from fabric.utils import abort
 
 from littlechef.lib import credentials
 from littlechef.settings import node_work_path, cookbook_paths
 
 
+# Path to local patch
+BASEDIR = os.path.abspath(os.path.dirname(__file__).replace('\\', '/'))
+
 def install(distro_type, distro, gems, version):
     with credentials():
         if distro_type == "debian":
@@ -42,23 +48,23 @@ def install(distro_type, distro, gems, version):
 def configure():
     """Deploy chef-solo specific files"""
     with credentials():
-        sudo('mkdir -p {0}/cache'.format(node_work_path))
-        sudo('umask 0377; touch solo.rb')
-        text = ""
-        text += 'file_cache_path "{0}/cache"'.format(node_work_path)
-        text += "\n"
+        # Ensure that config directories exist
+        cache_dir = "{0}/cache".format(node_work_path)
+        if not exists(cache_dir):
+            sudo('mkdir -p {0}'.format(cache_dir))
+        if not exists('/etc/chef'):
+            sudo('mkdir -p /etc/chef')
+        # Set parameters and upload solo.rb template
         reversed_cookbook_paths = cookbook_paths[:]
         reversed_cookbook_paths.reverse()
-        cookbook_paths_line = 'cookbook_path [{0}]'.format(', '.join(
+        cookbook_paths_list = '[{0}]'.format(', '.join(
             ['"{0}/{1}"'.format(node_work_path, x) \
                 for x in reversed_cookbook_paths]))
-        text += cookbook_paths_line + "\n"
-        text += cookbook_paths_line + "\n"
-        text += 'role_path "{0}/roles"'.format(node_work_path) + "\n"
-        text += 'data_bag_path "{0}/data_bags"'.format(node_work_path) + "\n"
-        append('solo.rb', text, use_sudo=True)
-        sudo('mkdir -p /etc/chef')
-        sudo('mv solo.rb /etc/chef/')
+        data = {'node_work_path': node_work_path,
+            'cookbook_paths_list': cookbook_paths_list}
+        upload_template(os.path.join(BASEDIR, 'solo.rb'), '/etc/chef/',
+            context=data, use_sudo=True, mode=0400)
+        sudo('chown root:root {0}'.format('/etc/chef/solo.rb'))
 
 
 def check_distro():
@@ -100,7 +106,7 @@ def check_distro():
             print "  Ubuntu: " + ", ".join(ubuntu_distros)
             print "  RHEL: " + ", ".join(rpm_distros)
             print "  Gentoo"
-            abort("Unsupported distro " + run('cat /etc/issue'))
+            abort("Unsupported distro '{0}'".format(output))
     return distro_type, distro
 
 
@@ -121,7 +127,10 @@ def _gem_apt_install():
     """Install Chef from gems for apt based distros"""
     with hide('stdout', 'running'):
         sudo('apt-get update')
-    sudo("DEBIAN_FRONTEND=noninteractive apt-get --yes install ruby ruby-dev libopenssl-ruby irb build-essential wget ssl-cert")
+    prefix = "DEBIAN_FRONTEND=noninteractive"
+    packages = "ruby ruby-dev libopenssl-ruby irb build-essential wget"
+    packages += " ssl-cert"
+    sudo('{0} apt-get --yes install {1}'.format(prefix, packages))
     _gem_install()
 
 
@@ -135,31 +144,56 @@ def _gem_rpm_install():
 
 def _apt_install(distro, version):
     """Install Chef for debian based distros"""
-    with hide('stdout', 'running'):
-        # we may not be able to install wget withtout 'apt-get update' first
-        sudo('apt-get update')
-    sudo('apt-get --yes install wget')
-    if version == "0.9":
-        version = ""
-    else:
-        version = "-" + version
-    append('opscode.list',
-        'deb http://apt.opscode.com/ {0}{1} main'.format(distro, version),
-            use_sudo=True)
-    sudo('mv opscode.list /etc/apt/sources.list.d/')
-    gpg_key = "http://apt.opscode.com/packages@opscode.com.gpg.key"
-    sudo('wget -qO - {0} | sudo apt-key add -'.format(gpg_key))
-    with hide('stdout', 'running'):
-        sudo('apt-get update')
-    with show('running'):
-        sudo('apt-get --yes install chef')
+    with settings(hide('stdout', 'running')):
+        with settings(hide('warnings'), warn_only=True):
+            wget_is_installed = sudo('which wget')
+            if wget_is_installed.failed:
+                # Install wget
+                print "Installing wget..."
+                # we may not be able to install wget withtout 'apt-get update' first
+                sudo('apt-get update')
+                output = sudo('apt-get --yes install wget')
+                if output.failed:
+                    print(colors.red("Error while installing wget:"))
+                    abort(output.lstrip("\\n"))
+        # Add Opscode debia repo
+        print("Setting up Opscode repository...")
+        if version == "0.9":
+            version = ""
+        else:
+            version = "-" + version
+        append('opscode.list',
+            'deb http://apt.opscode.com/ {0}{1} main'.format(distro, version),
+                use_sudo=True)
+        sudo('mv opscode.list /etc/apt/sources.list.d/')
+        # Add repository GPG key
+        gpg_key = "http://apt.opscode.com/packages@opscode.com.gpg.key"
+        sudo('wget -qO - {0} | sudo apt-key add -'.format(gpg_key))
+        # Load packages from new repository
+        with settings(hide('warnings'), warn_only=True):
+            output = sudo('apt-get update')
+            if output.failed:
+                print(colors.red("Error while executing apt-get install chef:"))
+                abort(output)
+        # Install Chef Solo
+        print("Installing Chef Solo")
+        # Ensure we don't get asked for the Chef Server
+        command = "echo chef chef/chef_server_url select ''"
+        command += " | debconf-set-selections"
+        sudo(command)
+        with settings(hide('warnings'), warn_only=True):
+            output = sudo('apt-get --yes install chef')
+            if output.failed:
+                print(colors.red("Error while executing 'apt-get install chef':"))
+                abort(output)
 
-    # We only want chef-solo, kill chef-client and remove it from init process
-    sudo('update-rc.d -f chef-client remove')
-    import time
-    time.sleep(0.5)
-    with settings(hide('warnings', 'stdout', 'running'), warn_only=True):
-        sudo('pkill chef-client')
+        # We only want chef-solo, kill chef-client and remove it from init process
+        sudo('update-rc.d -f chef-client remove')
+        with settings(hide('warnings'), warn_only=True):
+            output = sudo('service chef-client stop')
+        if output.failed:
+            # Probably an older distro
+            sudo('/etc/init.d/chef-client stop')
 
 
 def _add_rpm_repos():
@@ -167,13 +201,17 @@ def _add_rpm_repos():
     with show('running'):
         # Install the EPEL Yum Repository.
         with settings(hide('warnings', 'running'), warn_only=True):
-            output = sudo('rpm -Uvh http://download.fedora.redhat.com/pub/epel/5/i386/epel-release-5-4.noarch.rpm')
+            repo_url = "http://download.fedora.redhat.com"
+            repo_path = "/pub/epel/5/i386/epel-release-5-4.noarch.rpm"
+            output = sudo('rpm -Uvh {0}{1}'.format(repo_url, repo_path))
             installed = "package epel-release-5-4.noarch is already installed"
             if output.failed and installed not in output:
                 abort(output)
         # Install the ELFF Yum Repository.
         with settings(hide('warnings', 'running'), warn_only=True):
-            output = sudo('rpm -Uvh http://download.elff.bravenet.com/5/i386/elff-release-5-3.noarch.rpm')
+            repo_url = "http://download.elff.bravenet.com"
+            repo_path = "/5/i386/elff-release-5-3.noarch.rpm"
+            output = sudo('rpm -Uvh {0}{1}'.format(repo_url, repo_path))
             installed = "package elff-release-5-3.noarch is already installed"
             if output.failed and installed not in output:
                 abort(output)
